@@ -1,8 +1,19 @@
 from bisect import bisect_right, insort_right
 from collections.abc import MutableMapping
+import sys
+from typing import Any, Dict, Iterator, List
+from typing import MutableMapping as TypingMutableMapping
+from typing import Tuple, TypeVar
+
+T = TypeVar("T")
+
+if sys.version_info >= (3, 9):  # pragma: no cover
+    _MutableMapping = MutableMapping
+else:  # pragma: no cover
+    _MutableMapping = TypingMutableMapping
 
 
-class FloorDict(MutableMapping):
+class FloorDict(_MutableMapping[int, T]):
     """A dict where keys are int, and accessing a key will use the closest lower one.
 
     Differences from dict:
@@ -11,64 +22,62 @@ class FloorDict(MutableMapping):
      - obj[key, True] will return the real index of the value in the form (index, obj[key])
     """
 
-    def __init__(self):
-        self._dict = {}
-        self._keys = []  # sorted
+    def __init__(self) -> None:
+        self._dict: Dict[int, T] = {}
+        self._keys: List[int] = []  # sorted
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"FloorDict<{self._dict!r}>"
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[int]:
         return iter(self._keys)
 
-    def __reversed__(self):
+    def __reversed__(self) -> Iterator[int]:
         return reversed(self._keys)
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._keys)
 
-    def _key_index(self, key):
+    def _key_index(self, key: int) -> int:
         index = bisect_right(self._keys, key) - 1
         if index < 0:
             raise KeyError(key)
         return index
 
-    def __getitem__(self, key):
-        with_index = False
-        if isinstance(key, tuple) and len(key) == 2:
-            key, with_index = key
+    def get_with_index(self, key: int) -> Tuple[int, T]:
         if not isinstance(key, int):
             raise TypeError("Invalid key")
         index = self._keys[self._key_index(key)]
         value = self._dict[index]
-        if with_index:
-            return (index, value)
-        return value
+        return (index, value)
 
-    def __setitem__(self, key, value):
+    def __getitem__(self, key: int) -> T:
+        return self.get_with_index(key)[1]
+
+    def __setitem__(self, key: int, value: T) -> None:
         if not isinstance(key, int):
             raise TypeError("Invalid key")
         if key not in self._dict:  # prevent duplicates in _keys
             insort_right(self._keys, key)
         self._dict[key] = value
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: int) -> None:
         del self._dict[key]
         # the key is an exact index (otherwise KeyError raised on last line)
         self._keys.pop(self._key_index(key))
 
     @property
-    def last_key(self):
+    def last_key(self) -> int:
         if not self._keys:
             raise KeyError("dictionary is empty")
         return self._keys[-1]
 
     @property
-    def last_item(self):
+    def last_item(self) -> T:
         return self._dict[self.last_key]
 
 
-def parse_mode(mode):
+def parse_mode(mode: str) -> Tuple[str, bool, bool]:
     """Parse a mode used in open.
 
     Order is not considered at all.
@@ -90,7 +99,7 @@ def parse_mode(mode):
     return (mode_base, mode_base == "r", mode_base != "r")
 
 
-def proxy_property(attribute, proxy):
+def proxy_property(attribute: str, proxy: str) -> Any:
     """Create a property that is a proxy to an attribute of an attribute.
 
     Example:
@@ -108,15 +117,24 @@ def proxy_property(attribute, proxy):
     If the proxy is None, then use a local value instead,
     which acts as a temporary storage in the meanwhile.
     """
-    not_proxied_value = None
 
-    def getter(obj):
+    #
+    # Typing note
+    #
+    # There is no real way to type properties returned by a function,
+    # not to speak about the arbitrary getattr/setattr.
+    # This explains the use of Any everywhere
+    #
+
+    not_proxied_value: Any = None
+
+    def getter(obj: Any) -> Any:
         dest = getattr(obj, proxy)
         if dest is None:
             return not_proxied_value
         return getattr(dest, attribute)
 
-    def setter(obj, value):
+    def setter(obj: Any, value: Any) -> None:
         dest = getattr(obj, proxy)
         if dest is None:
             nonlocal not_proxied_value
