@@ -1,10 +1,20 @@
 from itertools import chain, product
 from pathlib import Path
+from typing import TYPE_CHECKING, Callable, Iterator, Tuple
 
 import pytest
 
+if TYPE_CHECKING:
+    from typing import List
 
-def pytest_addoption(parser):
+    # see https://github.com/pytest-dev/pytest/issues/7469
+    # for pytest exporting from pytest and not _pytest
+    from _pytest.config import Config
+    from _pytest.config.argparsing import Parser
+    from _pytest.nodes import Item
+
+
+def pytest_addoption(parser: "Parser") -> None:
     parser.addoption(
         "--generate-integration-files",
         action="store_true",
@@ -13,7 +23,7 @@ def pytest_addoption(parser):
     )
 
 
-def pytest_collection_modifyitems(config, items):
+def pytest_collection_modifyitems(config: "Config", items: "List[Item]") -> None:
     root = Path(__file__).parent.parent
     for item in items:
         relative = Path(item.fspath).parent.relative_to(root)
@@ -41,13 +51,13 @@ _DATA_PATTERN = bytes(
 
 
 @pytest.fixture(scope="session")
-def data_pattern():
+def data_pattern() -> bytes:
     return _DATA_PATTERN
 
 
 @pytest.fixture(scope="session")
-def data_pattern_locate():
-    def locate(data):
+def data_pattern_locate() -> Iterator[Callable[[bytes], Tuple[int, int]]]:
+    def locate(data: bytes) -> Tuple[int, int]:
         if len(data) < 3:
             raise ValueError("data to short")
         return (_DATA_PATTERN.index(data), len(data))
