@@ -1,4 +1,5 @@
 from io import SEEK_SET, BytesIO, UnsupportedOperation
+from typing import Callable, Iterator, Tuple, cast
 from unittest.mock import Mock, call
 
 import pytest
@@ -15,31 +16,31 @@ BLOCK_BYTES = bytes.fromhex(
 )
 
 
-def create_fileobj(data):
+def create_fileobj(data: bytes) -> Mock:
     raw = BytesIO(data)
     mock = Mock(wraps=raw)
-    mock.__class__ = IOAbstract  # needs to be subclass of IOAbstract
+    mock.__class__ = cast(Mock, IOAbstract)  # needs to be subclass of IOAbstract
     mock.__len__ = lambda _: len(raw.getvalue())
     return mock
 
 
 @pytest.fixture
-def fileobj():
+def fileobj() -> Iterator[Mock]:
     yield create_fileobj(BLOCK_BYTES)
 
 
 @pytest.fixture
-def fileobj_empty():
+def fileobj_empty() -> Iterator[Mock]:
     yield create_fileobj(b"")
 
 
 @pytest.fixture(autouse=True)
-def patch_buffer_size(monkeypatch):
+def patch_buffer_size(monkeypatch: pytest.MonkeyPatch) -> None:
     monkeypatch.setattr(BlockRead, "read_size", 17)
 
 
 @pytest.fixture
-def compressor(monkeypatch):
+def compressor(monkeypatch: pytest.MonkeyPatch) -> Iterator[Mock]:
     mock = Mock()
     monkeypatch.setattr(block_module, "LZMACompressor", mock)
     yield mock.return_value
@@ -53,7 +54,9 @@ def compressor(monkeypatch):
 #
 
 
-def test_read_all(fileobj, data_pattern_locate):
+def test_read_all(
+    fileobj: Mock, data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     block = XZBlock(fileobj, 1, 89, 100)
     assert block.tell() == 0
     assert data_pattern_locate(block.read()) == (0, 100)
@@ -79,7 +82,9 @@ def test_read_all(fileobj, data_pattern_locate):
     ]
 
 
-def test_read_seek_forward(fileobj, data_pattern_locate):
+def test_read_seek_forward(
+    fileobj: Mock, data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     block = XZBlock(fileobj, 1, 89, 100)
     assert block.tell() == 0
 
@@ -128,7 +133,9 @@ def test_read_seek_forward(fileobj, data_pattern_locate):
     fileobj.method_calls.clear()
 
 
-def test_read_seek_backward(fileobj, data_pattern_locate):
+def test_read_seek_backward(
+    fileobj: Mock, data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     block = XZBlock(fileobj, 1, 89, 100)
     assert block.tell() == 0
 
@@ -172,7 +179,9 @@ def test_read_seek_backward(fileobj, data_pattern_locate):
     fileobj.method_calls.clear()
 
 
-def test_read_wrong_uncompressed_size_too_small(fileobj, data_pattern_locate):
+def test_read_wrong_uncompressed_size_too_small(
+    fileobj: Mock, data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     block = XZBlock(fileobj, 1, 89, 99)
 
     # read all but last byte
@@ -184,7 +193,9 @@ def test_read_wrong_uncompressed_size_too_small(fileobj, data_pattern_locate):
     assert str(exc_info.value) == "block: error while decompressing: Corrupt input data"
 
 
-def test_read_wrong_uncompressed_size_too_big(fileobj, data_pattern_locate):
+def test_read_wrong_uncompressed_size_too_big(
+    fileobj: Mock, data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     block = XZBlock(fileobj, 1, 89, 101)
 
     # read all but last byte
@@ -196,7 +207,9 @@ def test_read_wrong_uncompressed_size_too_big(fileobj, data_pattern_locate):
     assert str(exc_info.value) == "block: error while decompressing: Corrupt input data"
 
 
-def test_read_wrong_block_padding(data_pattern_locate):
+def test_read_wrong_block_padding(
+    data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     fileobj = IOStatic(BLOCK_BYTES[:-5] + b"\xff" + BLOCK_BYTES[-4:])
     block = XZBlock(fileobj, 1, 89, 100)
 
@@ -209,7 +222,9 @@ def test_read_wrong_block_padding(data_pattern_locate):
     assert str(exc_info.value) == "block: error while decompressing: Corrupt input data"
 
 
-def test_read_wrong_check(data_pattern_locate):
+def test_read_wrong_check(
+    data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     fileobj = IOStatic(BLOCK_BYTES[:-4] + b"\xff" * 4)
 
     block = XZBlock(fileobj, 1, 89, 100)
@@ -223,7 +238,7 @@ def test_read_wrong_check(data_pattern_locate):
     assert str(exc_info.value) == "block: error while decompressing: Corrupt input data"
 
 
-def test_read_truncated_data():
+def test_read_truncated_data() -> None:
     fileobj = create_fileobj(
         bytes.fromhex(
             # header
@@ -240,7 +255,9 @@ def test_read_truncated_data():
     assert str(exc_info.value) == "block: data eof"
 
 
-def test_read_decompressor_eof(data_pattern_locate):
+def test_read_decompressor_eof(
+    data_pattern_locate: Callable[[bytes], Tuple[int, int]]
+) -> None:
     fileobj = IOStatic(
         bytes.fromhex(
             # one block
@@ -271,12 +288,12 @@ def test_read_decompressor_eof(data_pattern_locate):
 #
 
 
-def test_writable(fileobj):
+def test_writable(fileobj: Mock) -> None:
     block = XZBlock(fileobj, 1, 89, 100)
     assert not block.writable()
 
 
-def test_writable_empty(fileobj_empty):
+def test_writable_empty(fileobj_empty: Mock) -> None:
     block = XZBlock(fileobj_empty, 1, 0, 0)
     assert block.writable()
 
@@ -286,7 +303,7 @@ def test_writable_empty(fileobj_empty):
 #
 
 
-def test_write_once(fileobj_empty):
+def test_write_once(fileobj_empty: Mock) -> None:
     with XZBlock(fileobj_empty, 1, 0, 0) as block:
         block.write(b"Hello, world!\n")
         assert block.tell() == 14
@@ -305,7 +322,7 @@ def test_write_once(fileobj_empty):
     ]
 
 
-def test_write_multiple(fileobj_empty):
+def test_write_multiple(fileobj_empty: Mock) -> None:
     with XZBlock(fileobj_empty, 1, 0, 0) as block:
         block.write(b"Hello,")
         assert block.tell() == 6
@@ -330,7 +347,7 @@ def test_write_multiple(fileobj_empty):
 
 
 @pytest.mark.parametrize("pos", [0, 42, 100, 200])
-def test_write_existing(fileobj, pos):
+def test_write_existing(fileobj: Mock, pos: int) -> None:
     block = XZBlock(fileobj, 1, 89, 100)
     block.seek(pos)
     with pytest.raises(UnsupportedOperation):
@@ -338,7 +355,7 @@ def test_write_existing(fileobj, pos):
         block.write(b"a")
 
 
-def test_write_compressor_error_0(fileobj_empty, compressor):
+def test_write_compressor_error_0(fileobj_empty: Mock, compressor: Mock) -> None:
     compressor.compress.return_value = create_xz_header(0)
     with XZBlock(fileobj_empty, 1, 0, 0) as block:
         with pytest.raises(XZError) as exc_info:
@@ -346,7 +363,7 @@ def test_write_compressor_error_0(fileobj_empty, compressor):
     assert str(exc_info.value) == "block: compressor header"
 
 
-def test_write_compressor_error_1(fileobj_empty, compressor):
+def test_write_compressor_error_1(fileobj_empty: Mock, compressor: Mock) -> None:
     compressor.compress.return_value = create_xz_header(1)
     compressor.flush.return_value = create_xz_index_footer(0, [(13, 37), (4, 2)])
     with pytest.raises(XZError) as exc_info:
@@ -355,7 +372,7 @@ def test_write_compressor_error_1(fileobj_empty, compressor):
     assert str(exc_info.value) == "block: compressor footer check"
 
 
-def test_write_compressor_error_2(fileobj_empty, compressor):
+def test_write_compressor_error_2(fileobj_empty: Mock, compressor: Mock) -> None:
     compressor.compress.return_value = create_xz_header(1)
     compressor.flush.return_value = create_xz_index_footer(1, [(13, 37), (4, 2)])
     with pytest.raises(XZError) as exc_info:
@@ -364,7 +381,7 @@ def test_write_compressor_error_2(fileobj_empty, compressor):
     assert str(exc_info.value) == "block: compressor index records length"
 
 
-def test_write_compressor_error_3(fileobj_empty, compressor):
+def test_write_compressor_error_3(fileobj_empty: Mock, compressor: Mock) -> None:
     compressor.compress.return_value = create_xz_header(1)
     compressor.flush.return_value = create_xz_index_footer(1, [(34, 1337)])
     with pytest.raises(XZError) as exc_info:
@@ -378,7 +395,7 @@ def test_write_compressor_error_3(fileobj_empty, compressor):
 #
 
 
-def test_truncate_empty_zero(fileobj_empty):
+def test_truncate_empty_zero(fileobj_empty: Mock) -> None:
     with XZBlock(fileobj_empty, 1, 0, 0) as block:
         block.truncate(0)
         assert block.tell() == 0
@@ -390,7 +407,7 @@ def test_truncate_empty_zero(fileobj_empty):
     assert not fileobj_empty.method_calls
 
 
-def test_truncate_empty_fill(fileobj_empty):
+def test_truncate_empty_fill(fileobj_empty: Mock) -> None:
     with XZBlock(fileobj_empty, 1, 0, 0) as block:
         block.truncate(42)
         assert block.tell() == 0
@@ -410,7 +427,7 @@ def test_truncate_empty_fill(fileobj_empty):
 
 
 @pytest.mark.parametrize("size", [0, 42, 100, 200])
-def test_truncate_existing(fileobj, size):
+def test_truncate_existing(fileobj: Mock, size: int) -> None:
     block = XZBlock(fileobj, 1, 89, 100)
     with pytest.raises(UnsupportedOperation):
         # block is not empty, so not writable
